
###############################################################################################
#  AN EXAMPLE TO FIT THE MULTIDIMENSIONAL ITEM RESPONSE MODEL: Bayesian Inference             #      
#                                                                                             #
# Data contain answers of 1111 respondent to 21 items of Beck Depression Inventory (BDI)      #
# Data are described in Fragoso, T. M. and Cri, M. (2013). Improving psychometric assessment #      
# of the Beck Depression Inventory using Multidimensional Item Response Theory. Biometrical   #
# Journal, 55,  527-540                                                                       #
###############################################################################################



# install package foreign
#install.packages("foreign") 

#read data set

require(foreign)
wd="C:\\Users\\Jorge Luis\\Copy\\MinicursTRI\\Exemplos\\Multidimensional"
setwd(wd)
bdi=read.spss("bdi Univ - Tengdico.sav")
a=data.frame(bdi)
bdiitems=a[,4:24]


y=as.matrix(bdiitems)
colnames(y) <- NULL 

n=nrow(bdiitems)
I=ncol(bdiitems)

data<-list(y=y,n=n,I=I)

inits<-function(){list(a1=c(rep(1,I)),a2=c(rep(1,I)),
b=c(rep(0,I)),theta1=c(rep(0.5,n)),theta2=c(rep(0.5,n)))}

parameters<-c("a1","a2","b","mdific","mdisc","a1star","a2star","theta1","theta2")

n.iter=1400  #Consider 24000
n.burnin=400 #Consider 4000
n.thin=1     #Consider 20



#Usando WinBUGS
#################
#To install WinBUGS see http://www.wcsmalaysia.org/analysis/WinBUGS_install.htm

library(R2WinBUGS)
#bugs directory home
bd="C:/Program Files/WinBUGS14/"

bayes2LMW<-bugs(data,inits=inits,parameters.to.save=parameters,
model.file="Logistic 2LM Model.txt",working.directory=wd,
n.chains=1,n.iter=n.iter,n.burnin=n.burnin,n.thin=n.thin,bugs.directory=bd)


plot(bayes2LMW)
print(bayes2LMW,digits=2)


#convergence analysis

bayes2LMW2<-bugs(data,inits=inits,parameters.to.save=parameters,
model.file="Logistic 2LM Model.txt",working.directory=wd,codaPkg = TRUE,
n.chains=1,n.iter=n.iter,n.burnin=n.burnin,n.thin=n.thin,bugs.directory=bd)

library("coda")
codaobject <- read.bugs(bayes2LMW2)
summary(codaobject)
effectiveSize(codaobject)

#parameter a1
geweke.diag(codaobject[,c(1:21)])
plot(codaobject[,c(1:21)])
densityplot(codaobject[,c(1:21)]) 
xyplot(codaobject[,c(1:21)])
acfplot(codaobject[,c(1:21)])

#parameter a1star
geweke.diag(codaobject[,c(22:42)])
plot(codaobject[,c(22:42)])
densityplot(codaobject[,c(22:42)]) 
xyplot(codaobject[,c(22:42)])
acfplot(codaobject[,c(22:42)])

#parameter a2
geweke.diag(codaobject[,c(43:63)])
plot(codaobject[,c(43:63)])
densityplot(codaobject[,c(43:63)]) 
xyplot(codaobject[,c(43:63)])
acfplot(codaobject[,c(43:63)]) 

#parameter a2star
geweke.diag(codaobject[,c(64:84)])
plot(codaobject[,c(64:84)])
densityplot(codaobject[,c(64:84)]) 
xyplot(codaobject[,c(64:84)])
acfplot(codaobject[,c(64:84)])


#parameter b
geweke.diag(codaobject[,c(85:105)])
plot(codaobject[,c(85:105)])
densityplot(codaobject[,c(85:105)]) 
xyplot(codaobject[,c(85:105)])
acfplot(codaobject[,c(85:105)])

#parameter mdific
geweke.diag(codaobject[,c(106:127)])
plot(codaobject[,c(106:127)])
densityplot(codaobject[,c(106:127)]) 
xyplot(codaobject[,c(106:127)])
acfplot(codaobject[,c(106:127)])

#parameter mdisc
geweke.diag(codaobject[,c(128:148)])
plot(codaobject[,c(128:148)])
densityplot(codaobject[,c(128:148)]) 
xyplot(codaobject[,c(128:148)])
acfplot(codaobject[,c(128:148)])


#Note. WinBugs and R2WinBUGS is more quickly that OpenBUGS with R2OpenBUGS or brugs


